============
cfn-pyplates
============

Amazon Web Services CloudFormation templates, generated with Python!

.. image:: https://travis-ci.org/seandst/cfn-pyplates.png
    :target: https://travis-ci.org/seandst/cfn-pyplates/

Doumentation
============

https://cfn-pyplates.readthedocs.org/


.. This include doesn't work, but one day it might!
    https://github.com/github/markup/issues/172

.. include:: docs/source/intro.rst

